@@ -15,20 +15,15 @@ var BoundingBoxD_8h =
     [ "BoundingBox6Ds", "BoundingBoxD_8h.html#ac5b318d1848a44117db30f65e6196d18", null ],
     [ "BoundingBoxKD", "BoundingBoxD_8h.html#a4882602f27f726c425028dc402de4562", null ],
     [ "BoundingBoxKDs", "BoundingBoxD_8h.html#ad077a80677a797fb8525bfde8bbd2f77", null ],
-    [ "get_bounding_box", "BoundingBoxD_8h.html#ab2f699cae36124beba794575ad967353", null ],
-    [ "get_bounding_box_d_geometry", "BoundingBoxD_8h.html#afb47f9e128b123012319726dff743d15", null ],
     [ "get_cube_d", "BoundingBoxD_8h.html#afc7bf8d6b520c4abfed644b0eb7b1288", null ],
     [ "get_cube_kd", "BoundingBoxD_8h.html#aecec6f9c6ca668315e6693773ac1c15f", null ],
     [ "get_edges", "BoundingBoxD_8h.html#a17aeb2742e60928cf687ef786530d44c", null ],
     [ "get_interiors_intersect", "BoundingBoxD_8h.html#ab00c98290b98833acf41b7cdfaa1a701", null ],
     [ "get_intersection", "BoundingBoxD_8h.html#a7d107e54c2f6c82ac6af484a62dba718", null ],
     [ "get_maximum_length", "BoundingBoxD_8h.html#a06143c1eada26a19c52b0727f8ab2028", null ],
-    [ "get_surface_area", "BoundingBoxD_8h.html#adec275b9df8ed7ded1ce9c47f13aecbc", null ],
     [ "get_union", "BoundingBoxD_8h.html#a5884c6b32a247dd314db4c33b92508b8", null ],
     [ "get_unit_bounding_box_d", "BoundingBoxD_8h.html#aefe76b06844e6f12a5c08da8673517b4", null ],
     [ "get_unit_bounding_box_kd", "BoundingBoxD_8h.html#aa88ff22c3c9a9a857314e714d69dea62", null ],
     [ "get_vertices", "BoundingBoxD_8h.html#a8d62bc96f3a84795ae43665423fe9414", null ],
-    [ "get_volume", "BoundingBoxD_8h.html#a94f280e1b578da3b5875fb157cfc7c68", null ],
-    [ "get_volume", "BoundingBoxD_8h.html#a7fe37764b7efa23604c80c9526f7f672", null ],
-    [ "set_bounding_box_d_geometry", "BoundingBoxD_8h.html#acc23cb82b5a2a16a73872f8dc1ceae4e", null ]
+    [ "get_volume", "BoundingBoxD_8h.html#a94f280e1b578da3b5875fb157cfc7c68", null ]
 ];
\ No newline at end of file
