@@ -6,5 +6,5 @@ var FormFactorTable_8h =
       [ "HEAVY_ATOMS", "FormFactorTable_8h.html#af6bcf28f95539cc1cfa91071938ee111a3e78408c5da97f92f0320182842ca34b", null ],
       [ "CA_ATOMS", "FormFactorTable_8h.html#af6bcf28f95539cc1cfa91071938ee111a77196265475c28f29ac633cce99e4c1a", null ]
     ] ],
-    [ "default_form_factor_table", "FormFactorTable_8h.html#ad5561a6eee31ca81413d395c70a70b6f", null ]
+    [ "get_default_form_factor_table", "FormFactorTable_8h.html#a4376a2c676c4c92975cbb4df0cb6d294", null ]
 ];
\ No newline at end of file
