@@ -9,13 +9,8 @@ var XYZR_8h =
     [ "XYZRsGeometry", "classIMP_1_1core_1_1XYZRsGeometry.html", "classIMP_1_1core_1_1XYZRsGeometry" ],
     [ "XYZRs", "XYZR_8h.html#a55244f032d68e041e9b58b424e2afca5", null ],
     [ "create_xyzr_particles", "XYZR_8h.html#ab187aead985c4fb93d7c4c8741fb00c8", null ],
-    [ "get_bounding_box_d_geometry", "XYZR_8h.html#a7af540f9ed2dd3fde2df28ca945ab02d", null ],
     [ "get_distance", "XYZR_8h.html#ad65d79ddb3c6e1db815d57f73c8f18ea", null ],
     [ "get_enclosing_sphere", "XYZR_8h.html#ac28cbff46cedec4186ab8e63a3c3b41b", null ],
-    [ "get_sphere_d_geometry", "XYZR_8h.html#ab4b8129895bd3a8ed9c8d24e92ecddbb", null ],
-    [ "get_sphere_d_geometry", "XYZR_8h.html#afcc24b50d1ea4e9107b3b41a9752c965", null ],
     [ "set_enclosing_radius", "XYZR_8h.html#a25735ab61a19f9813d051462afd24b2f", null ],
-    [ "set_enclosing_sphere", "XYZR_8h.html#a9f00e88e92a88b5ef349978fe737df7d", null ],
-    [ "set_sphere_d_geometry", "XYZR_8h.html#a0c5c86c54384203935b418c8ce1f75b9", null ],
-    [ "set_sphere_d_geometry", "XYZR_8h.html#a2e376dc37b3989846546d174abbea8ca", null ]
+    [ "set_enclosing_sphere", "XYZR_8h.html#a9f00e88e92a88b5ef349978fe737df7d", null ]
 ];
\ No newline at end of file
