@@ -9,11 +9,15 @@ var classIMP_1_1algebra_1_1GridD =
     [ "Vector", "classIMP_1_1algebra_1_1GridD.html#a15f2ce2b4dcaf0e6521d86a65e79ddc1", null ],
     [ "GridD", "classIMP_1_1algebra_1_1GridD.html#a97ccb184c448edc82741a0b8126ec750", null ],
     [ "GridD", "classIMP_1_1algebra_1_1GridD.html#aa575da807c4f8427657289c1725587c2", null ],
+    [ "GridD", "classIMP_1_1algebra_1_1GridD.html#ab96be5a02e7d8a1729e6b47e8f6b93da", null ],
     [ "GridD", "classIMP_1_1algebra_1_1GridD.html#a3d5363a55aec81dc831a332a57be4cfb", null ],
     [ "GridD", "classIMP_1_1algebra_1_1GridD.html#adb32bd20c18445dd15609b6d71ab6eff", null ],
+    [ "GridD", "classIMP_1_1algebra_1_1GridD.html#a1331afb93fdf474e352ce38076a1dd56", null ],
     [ "GridD", "classIMP_1_1algebra_1_1GridD.html#aec69617c1e10c1937ce5900f4b62fcd9", null ],
     [ "add_voxel", "classIMP_1_1algebra_1_1GridD.html#a24ba706b342d7dc7e3c5cb42ed64fccf", null ],
     [ "apply", "classIMP_1_1algebra_1_1GridD.html#a44ba6e822f80db8aee815c6cee9f6c42", null ],
+    [ "at", "classIMP_1_1algebra_1_1GridD.html#a6ed148a6870b552c9a0ece4fbade160f", null ],
+    [ "at", "classIMP_1_1algebra_1_1GridD.html#adb7e2e9c0cb96a26c31683ac51541273", null ],
     [ "extended_indexes_begin", "classIMP_1_1algebra_1_1GridD.html#a91df12851f5e94fb5d1eaa17228b74a6", null ],
     [ "extended_indexes_end", "classIMP_1_1algebra_1_1GridD.html#ab8d1e94d9e10cc7d56abf46cdbb71dd6", null ],
     [ "get_all_indexes", "classIMP_1_1algebra_1_1GridD.html#ab5a99d9b97fcdc767e77c1d218ab4cc3", null ],
@@ -25,8 +29,8 @@ var classIMP_1_1algebra_1_1GridD =
     [ "get_nearest_index", "classIMP_1_1algebra_1_1GridD.html#a81b743c5cc601b32b1eb1b31874afeb6", null ],
     [ "indexes_begin", "classIMP_1_1algebra_1_1GridD.html#a0e73f5094989644138b2df7a923e59f5", null ],
     [ "indexes_end", "classIMP_1_1algebra_1_1GridD.html#aa18ee2704ae69eff7db20ca04098fedf", null ],
-    [ "operator[]", "classIMP_1_1algebra_1_1GridD.html#adf5b3de175047e40a340c7acdb47b7d9", null ],
     [ "operator[]", "classIMP_1_1algebra_1_1GridD.html#a4253e432b3e29c9717dec9cdc29ba314", null ],
+    [ "operator[]", "classIMP_1_1algebra_1_1GridD.html#adf5b3de175047e40a340c7acdb47b7d9", null ],
     [ "set_bounding_box", "classIMP_1_1algebra_1_1GridD.html#ab560837a0b4afe66e89bfc0d628deaa8", null ],
     [ "show", "classIMP_1_1algebra_1_1GridD.html#a78af4bd3e1bd1b63d54335579df26fd4", null ],
     [ "voxels_begin", "classIMP_1_1algebra_1_1GridD.html#aba328c5e51d34efea9057707ac80695c", null ],
