@@ -11,5 +11,9 @@ var classIMP_1_1algebra_1_1Plane3D =
     [ "get_opposite", "classIMP_1_1algebra_1_1Plane3D.html#aaccbebe65a7c6c14a0bde93ab9b91363", null ],
     [ "get_point_on_plane", "classIMP_1_1algebra_1_1Plane3D.html#a06f9457bf6d5f681ffb4cc750112f7b9", null ],
     [ "get_projected", "classIMP_1_1algebra_1_1Plane3D.html#a854ba9b2d105a4b3fa05991b22ada40d", null ],
-    [ "show", "classIMP_1_1algebra_1_1Plane3D.html#afee3d77bc172a368fd342d47cecb77f1", null ]
+    [ "show", "classIMP_1_1algebra_1_1Plane3D.html#afee3d77bc172a368fd342d47cecb77f1", null ],
+    [ "get_area", "classIMP_1_1algebra_1_1Plane3D.html#a2ce4dc9bc8335a283d1993a24ed1130e", null ],
+    [ "get_bounding_box", "classIMP_1_1algebra_1_1Plane3D.html#aedce7034965a145fc52252f640761b26", null ],
+    [ "get_plane_3d_geometry", "classIMP_1_1algebra_1_1Plane3D.html#ade3bebd378b15acf3e134236ccf4a894", null ],
+    [ "set_plane_3d_geometry", "classIMP_1_1algebra_1_1Plane3D.html#a6e8806b130e7420d2a33e532c4ecfdcf", null ]
 ];
\ No newline at end of file
