@@ -1,6 +1,8 @@
 var classIMP_1_1atom_1_1BondsGeometry =
 [
     [ "BondsGeometry", "classIMP_1_1atom_1_1BondsGeometry.html#ab8515165c8c88285cd53a08c49c20027", null ],
+    [ "~BondsGeometry", "classIMP_1_1atom_1_1BondsGeometry.html#af10262d8d966b499333a2b4feabec3b1", null ],
+    [ "get_components", "classIMP_1_1atom_1_1BondsGeometry.html#a56f4a7834353e9019f9395903e65026f", null ],
     [ "get_type_name", "classIMP_1_1atom_1_1BondsGeometry.html#ab9cc1782efdfe7117ccf7f429c9ad539", null ],
     [ "get_version_info", "classIMP_1_1atom_1_1BondsGeometry.html#a9b10041993847edce5793ffe48613ddc", null ]
 ];
\ No newline at end of file
