@@ -1,8 +1,10 @@
 var classIMP_1_1atom_1_1CHARMMStereochemistryRestraint =
 [
     [ "CHARMMStereochemistryRestraint", "classIMP_1_1atom_1_1CHARMMStereochemistryRestraint.html#aa053a5423e162bc45edb28ed4777bf57", null ],
+    [ "CHARMMStereochemistryRestraint", "classIMP_1_1atom_1_1CHARMMStereochemistryRestraint.html#ae55a4983c41e935a811d933ba32a60c8", null ],
     [ "~CHARMMStereochemistryRestraint", "classIMP_1_1atom_1_1CHARMMStereochemistryRestraint.html#af4d71a4630c92aa822c0f551fc905864", null ],
     [ "do_get_inputs", "classIMP_1_1atom_1_1CHARMMStereochemistryRestraint.html#ae3c6fbf4de0399fd17a6e494464d2e1b", null ],
+    [ "get_full_pair_filter", "classIMP_1_1atom_1_1CHARMMStereochemistryRestraint.html#ae0b7827cf358f1b32252b217af963637", null ],
     [ "get_pair_filter", "classIMP_1_1atom_1_1CHARMMStereochemistryRestraint.html#a96a84aff0d2d9ea0401ae5cfb15c561f", null ],
     [ "get_type_name", "classIMP_1_1atom_1_1CHARMMStereochemistryRestraint.html#aa9353b5c58f6a0acb9c4bc2dfa4fa7fe", null ],
     [ "get_version_info", "classIMP_1_1atom_1_1CHARMMStereochemistryRestraint.html#aecb095b55db8c1b73ab429a54070d5f2", null ],
