@@ -12,6 +12,7 @@ var classIMP_1_1atom_1_1Selection =
     [ "Selection", "classIMP_1_1atom_1_1Selection.html#ad1607c56d5b295206039732b6c5d620b", null ],
     [ "Selection", "classIMP_1_1atom_1_1Selection.html#aa382f78f97cb063e198413d0bc25bce9", null ],
     [ "Selection", "classIMP_1_1atom_1_1Selection.html#a215267c1208e2b3cdfc150f2faa86dfe", null ],
+    [ "create_clone", "classIMP_1_1atom_1_1Selection.html#ab6e1290b1f07537af66b8438e9423447", null ],
     [ "get_hierarchies", "classIMP_1_1atom_1_1Selection.html#afe161e06395cbac13aa681457cad1a24", null ],
     [ "get_selected_particle_indexes", "classIMP_1_1atom_1_1Selection.html#adcf3ecd4cf8e2c04a906cf272b0330e6", null ],
     [ "get_selected_particles", "classIMP_1_1atom_1_1Selection.html#a2295bcd24896c8fcbdcea743f4f01fa8", null ],
@@ -24,9 +25,11 @@ var classIMP_1_1atom_1_1Selection =
     [ "set_chain_ids", "classIMP_1_1atom_1_1Selection.html#acdbbb7ee43426d18d25e8156f4c4a102", null ],
     [ "set_copy_index", "classIMP_1_1atom_1_1Selection.html#a0c05ce602cf890b36c27215f0457faf0", null ],
     [ "set_copy_indexes", "classIMP_1_1atom_1_1Selection.html#a2b1abb1ec178f5a03ad209a411e36c50", null ],
+    [ "set_difference", "classIMP_1_1atom_1_1Selection.html#a79306b9477cdce20dc3589eb1b5040bf", null ],
     [ "set_domain", "classIMP_1_1atom_1_1Selection.html#ab5a57597317ebe803b8cc1fc41aef83a", null ],
     [ "set_domains", "classIMP_1_1atom_1_1Selection.html#a2efbaacbb23fc9c88afcc840128b5e78", null ],
     [ "set_hierarchy_types", "classIMP_1_1atom_1_1Selection.html#aa2a947c2b84478de28b099b88924ff44", null ],
+    [ "set_intersection", "classIMP_1_1atom_1_1Selection.html#ab230edcc56bbc2163dcb2d8bb1a822f2", null ],
     [ "set_molecule", "classIMP_1_1atom_1_1Selection.html#ae96dcf41ae1e3ba865b24563ad41b7ba", null ],
     [ "set_molecules", "classIMP_1_1atom_1_1Selection.html#a979e892be89833c278010bc5cade2a25", null ],
     [ "set_particle_type", "classIMP_1_1atom_1_1Selection.html#aa2896c10f6a3bcc197e413bd09403e25", null ],
@@ -38,6 +41,8 @@ var classIMP_1_1atom_1_1Selection =
     [ "set_resolution", "classIMP_1_1atom_1_1Selection.html#a45b96d8418e4d70aaa9e3288faecf1e8", null ],
     [ "set_state_index", "classIMP_1_1atom_1_1Selection.html#add150ee8ebf300196dc5c0aa169a9096", null ],
     [ "set_state_indexes", "classIMP_1_1atom_1_1Selection.html#ae9b296352da61f058a02aa11037e19ab", null ],
+    [ "set_symmetric_difference", "classIMP_1_1atom_1_1Selection.html#adab4f65a622a2a377c6805ac3341049c", null ],
     [ "set_terminus", "classIMP_1_1atom_1_1Selection.html#a04ccdbbc4b29e285546aa9c91e60b274", null ],
+    [ "set_union", "classIMP_1_1atom_1_1Selection.html#a63be78e2118e882d1fb047b20b085368", null ],
     [ "show", "classIMP_1_1atom_1_1Selection.html#af221404aa37d09232e7f45906d71c207", null ]
 ];
\ No newline at end of file
