@@ -1,6 +1,8 @@
 var classIMP_1_1core_1_1RigidBodyDerivativesGeometry =
 [
     [ "RigidBodyDerivativesGeometry", "classIMP_1_1core_1_1RigidBodyDerivativesGeometry.html#a0096a1f0c7b5b08b92f30ec46238f299", null ],
+    [ "~RigidBodyDerivativesGeometry", "classIMP_1_1core_1_1RigidBodyDerivativesGeometry.html#a3f3450dfcdb3c1063d8ca081356eb62d", null ],
+    [ "get_components", "classIMP_1_1core_1_1RigidBodyDerivativesGeometry.html#a3542ee6deeb52972bc1575c0c004fce4", null ],
     [ "get_type_name", "classIMP_1_1core_1_1RigidBodyDerivativesGeometry.html#af821fcec1b80f33f5071fb4bad138fbe", null ],
     [ "get_version_info", "classIMP_1_1core_1_1RigidBodyDerivativesGeometry.html#a16298f3c9432ce84c5e83a899c889032", null ]
 ];
\ No newline at end of file
