@@ -1,6 +1,8 @@
 var classIMP_1_1core_1_1XYZRsGeometry =
 [
     [ "XYZRsGeometry", "classIMP_1_1core_1_1XYZRsGeometry.html#aca80015235b9af92bfa758f798f0e187", null ],
+    [ "~XYZRsGeometry", "classIMP_1_1core_1_1XYZRsGeometry.html#ac7bed4bcd93a3ef4476e29a91e36e0b6", null ],
+    [ "get_components", "classIMP_1_1core_1_1XYZRsGeometry.html#ae34c7fa456f7632f7ab9e85008cd4767", null ],
     [ "get_type_name", "classIMP_1_1core_1_1XYZRsGeometry.html#a72ea003a975bc9a4d8c621ec1c967c43", null ],
     [ "get_version_info", "classIMP_1_1core_1_1XYZRsGeometry.html#aa12d0f11e2c4dfe4f0b2e7c3758e0cf2", null ]
 ];
\ No newline at end of file
