@@ -1,6 +1,7 @@
 var classIMP_1_1em2d_1_1Em2DRestraint =
 [
-    [ "Em2DRestraint", "classIMP_1_1em2d_1_1Em2DRestraint.html#a044a7f9ab5250b7958e8a5a49f91241f", null ],
+    [ "Em2DRestraint", "classIMP_1_1em2d_1_1Em2DRestraint.html#afa25f2d0c9d7ea93a8adff957bcf51a7", null ],
+    [ "~Em2DRestraint", "classIMP_1_1em2d_1_1Em2DRestraint.html#a2eab2d1594bd4c491d0adfa1a2e17630", null ],
     [ "do_get_inputs", "classIMP_1_1em2d_1_1Em2DRestraint.html#a61357322aa33e8fb89e5dbd33975166d", null ],
     [ "get_registration_results", "classIMP_1_1em2d_1_1Em2DRestraint.html#acaf0010dcfe1d022f1ed720f3d991dfa", null ],
     [ "get_type_name", "classIMP_1_1em2d_1_1Em2DRestraint.html#ad3489b7a441b3ef9364f4626a67672fd", null ],
@@ -11,5 +12,5 @@ var classIMP_1_1em2d_1_1Em2DRestraint =
     [ "set_particles", "classIMP_1_1em2d_1_1Em2DRestraint.html#a4fff039bf0e2bf49c06583f83d254afa", null ],
     [ "set_variance_images", "classIMP_1_1em2d_1_1Em2DRestraint.html#a684fffc8d113ecb1e03cb8ff8e1c6fda", null ],
     [ "setup", "classIMP_1_1em2d_1_1Em2DRestraint.html#a3351edb9bbe8eab5297df9396542effd", null ],
-    [ "const", "classIMP_1_1em2d_1_1Em2DRestraint.html#a2d94b627d2bf2077d9885f398e803662", null ]
+    [ "unprotected_evaluate", "classIMP_1_1em2d_1_1Em2DRestraint.html#a9fa81bec49a718814361505ff8b0cf38", null ]
 ];
\ No newline at end of file
