@@ -1,6 +1,7 @@
 var classIMP_1_1em_1_1EnvelopePenetrationRestraint =
 [
     [ "EnvelopePenetrationRestraint", "classIMP_1_1em_1_1EnvelopePenetrationRestraint.html#acdc0d23301996c084c90fccddc2f7478", null ],
+    [ "~EnvelopePenetrationRestraint", "classIMP_1_1em_1_1EnvelopePenetrationRestraint.html#a3f4dd9d45b5ff13d9b6e9702b66030ed", null ],
     [ "add_particle", "classIMP_1_1em_1_1EnvelopePenetrationRestraint.html#aab72347fd0017474d391ef515b00f69a", null ],
     [ "add_particles", "classIMP_1_1em_1_1EnvelopePenetrationRestraint.html#a76c2acc6f22adf240f070282ca6ce75d", null ],
     [ "clear_particles", "classIMP_1_1em_1_1EnvelopePenetrationRestraint.html#a5eb649ca4a75738a1fffaf336964d688", null ],
@@ -16,5 +17,5 @@ var classIMP_1_1em_1_1EnvelopePenetrationRestraint =
     [ "reserve_particles", "classIMP_1_1em_1_1EnvelopePenetrationRestraint.html#a7f71f635f30887b212abc1f7c8e82bbf", null ],
     [ "set_particles", "classIMP_1_1em_1_1EnvelopePenetrationRestraint.html#a89786db5a2aa1d7aab6cdf28c6af09c0", null ],
     [ "set_particles_order", "classIMP_1_1em_1_1EnvelopePenetrationRestraint.html#af42ebdd1fd46f21ce6d506669715d014", null ],
-    [ "const", "classIMP_1_1em_1_1EnvelopePenetrationRestraint.html#ae51de338b3a290b7248a12ec9267aa14", null ]
+    [ "unprotected_evaluate", "classIMP_1_1em_1_1EnvelopePenetrationRestraint.html#a73bcd18c899decbe79668687052339f2", null ]
 ];
\ No newline at end of file
