@@ -1,7 +1,7 @@
 var classIMP_1_1gsl_1_1QuasiNewton =
 [
     [ "QuasiNewton", "classIMP_1_1gsl_1_1QuasiNewton.html#a5db583f97a00be6ecbea53fc6e5b499d", null ],
-    [ "QuasiNewton", "classIMP_1_1gsl_1_1QuasiNewton.html#a12d34b71b430745ab1ef3e0a67e57bff", null ],
+    [ "~QuasiNewton", "classIMP_1_1gsl_1_1QuasiNewton.html#a1a83bb25733ef0979ddc1bb45bfbb984", null ],
     [ "do_optimize", "classIMP_1_1gsl_1_1QuasiNewton.html#ab50544b512b0b8973a1d44263313b5d4", null ],
     [ "get_type_name", "classIMP_1_1gsl_1_1QuasiNewton.html#adce8da5c034c46a808c750f163286948", null ],
     [ "get_version_info", "classIMP_1_1gsl_1_1QuasiNewton.html#afcdd270312e2de59ded9b757773722cb", null ],
