@@ -4,11 +4,12 @@ var classIMP_1_1isd_1_1TALOSRestraint =
     [ "TALOSRestraint", "classIMP_1_1isd_1_1TALOSRestraint.html#a1363aeb8875066903b5e3fa7c5782a96", null ],
     [ "TALOSRestraint", "classIMP_1_1isd_1_1TALOSRestraint.html#aaac74730bac287751f2f442dcfd74ddc", null ],
     [ "TALOSRestraint", "classIMP_1_1isd_1_1TALOSRestraint.html#ad7b9a4e42e2d1c34266d136d71d79467", null ],
+    [ "~TALOSRestraint", "classIMP_1_1isd_1_1TALOSRestraint.html#a98ca9180abf96874fce1c038e0222c31", null ],
     [ "do_get_inputs", "classIMP_1_1isd_1_1TALOSRestraint.html#aa10f347d2bafe6e6af375d2b99767792", null ],
     [ "get_chiexp", "classIMP_1_1isd_1_1TALOSRestraint.html#a2af91872502729660481fb931cce8dc3", null ],
     [ "get_probability", "classIMP_1_1isd_1_1TALOSRestraint.html#a4f75a86bc726a143db29774880dac51a", null ],
     [ "get_R0", "classIMP_1_1isd_1_1TALOSRestraint.html#a24eca128484c7e44de123b2b0bb554e6", null ],
     [ "get_type_name", "classIMP_1_1isd_1_1TALOSRestraint.html#ac00cd0a17732f3b6987bd411d7cedb7e", null ],
     [ "get_version_info", "classIMP_1_1isd_1_1TALOSRestraint.html#ae0a00a9fb5284653bc99dc73b8c7dce8", null ],
-    [ "const", "classIMP_1_1isd_1_1TALOSRestraint.html#a0fadab465f7c3276dd4ed4b21fdc2a94", null ]
+    [ "unprotected_evaluate", "classIMP_1_1isd_1_1TALOSRestraint.html#ad1f172b6c70d1f7f7ae6bdb65338161a", null ]
 ];
\ No newline at end of file
