@@ -1,9 +1,12 @@
 var classIMP_1_1isd_1_1WeightMover =
 [
     [ "WeightMover", "classIMP_1_1isd_1_1WeightMover.html#ae5c4dcef1a30c4c50602c5f619be6c14", null ],
+    [ "~WeightMover", "classIMP_1_1isd_1_1WeightMover.html#a9fbdefb38b31a61d0d62c72cf0f5c448", null ],
     [ "do_get_inputs", "classIMP_1_1isd_1_1WeightMover.html#adbe58cd1b9a9a32f45243e8f0b686bc9", null ],
     [ "do_propose", "classIMP_1_1isd_1_1WeightMover.html#a633e2756b8b6fcb8898009453fc40a31", null ],
     [ "do_reject", "classIMP_1_1isd_1_1WeightMover.html#ae2c3169171e0102b9a42b91df171bf78", null ],
+    [ "get_radius", "classIMP_1_1isd_1_1WeightMover.html#aaa50f4555a26b5374636be1d0bd7f400", null ],
     [ "get_type_name", "classIMP_1_1isd_1_1WeightMover.html#aa55a2ca10eefc6badcb6e0e93118e6bf", null ],
-    [ "get_version_info", "classIMP_1_1isd_1_1WeightMover.html#a0c10bc59e2578be668f2aa264cbeb94a", null ]
+    [ "get_version_info", "classIMP_1_1isd_1_1WeightMover.html#a0c10bc59e2578be668f2aa264cbeb94a", null ],
+    [ "set_radius", "classIMP_1_1isd_1_1WeightMover.html#af2f6f450492dbc579cc87d6dcaba9521", null ]
 ];
\ No newline at end of file
