@@ -1,9 +1,10 @@
 var classIMP_1_1isd_1_1vonMisesKappaJeffreysRestraint =
 [
     [ "vonMisesKappaJeffreysRestraint", "classIMP_1_1isd_1_1vonMisesKappaJeffreysRestraint.html#a69c0b213ef8e9ca483f36243c1bd4826", null ],
+    [ "~vonMisesKappaJeffreysRestraint", "classIMP_1_1isd_1_1vonMisesKappaJeffreysRestraint.html#a4090f5b060456e563c2d9e13cfe17a55", null ],
     [ "do_get_inputs", "classIMP_1_1isd_1_1vonMisesKappaJeffreysRestraint.html#acd20283351d8ba30296b304f3ae1ca24", null ],
     [ "get_probability", "classIMP_1_1isd_1_1vonMisesKappaJeffreysRestraint.html#abc4bec85bd192c4bdf7ca357218d9b47", null ],
     [ "get_type_name", "classIMP_1_1isd_1_1vonMisesKappaJeffreysRestraint.html#af81f6baa35868889ba14ccbd23dc2020", null ],
     [ "get_version_info", "classIMP_1_1isd_1_1vonMisesKappaJeffreysRestraint.html#a89fc5a466ec44c2cb0d779ee26b2a5ed", null ],
-    [ "const", "classIMP_1_1isd_1_1vonMisesKappaJeffreysRestraint.html#a0c086632a29d1263b64e0fbe10dddbc0", null ]
+    [ "unprotected_evaluate", "classIMP_1_1isd_1_1vonMisesKappaJeffreysRestraint.html#a935a6da05c9775905a371f07a95ee0fe", null ]
 ];
\ No newline at end of file
