@@ -1,7 +1,6 @@
 var classIMP_1_1kernel_1_1Restraint =
 [
     [ "Restraint", "classIMP_1_1kernel_1_1Restraint.html#adb99dadac98213da50dd23d8a72db481", null ],
-    [ "Restraint", "classIMP_1_1kernel_1_1Restraint.html#ab9a1380c109416ccc0234b4faba9969e", null ],
     [ "add_score_and_derivatives", "classIMP_1_1kernel_1_1Restraint.html#a58d5464f91a4bb7e509820c6c9fc6e37", null ],
     [ "create_current_decomposition", "classIMP_1_1kernel_1_1Restraint.html#abad714322450bb54ecc15dbe8cfcc501", null ],
     [ "create_decomposition", "classIMP_1_1kernel_1_1Restraint.html#ad9dc68fdb3e35bbbf54d56d4322fccce", null ],
@@ -10,8 +9,6 @@ var classIMP_1_1kernel_1_1Restraint =
     [ "do_create_current_decomposition", "classIMP_1_1kernel_1_1Restraint.html#a76076de2a98a3065b346bd5dfb85e756", null ],
     [ "do_create_decomposition", "classIMP_1_1kernel_1_1Restraint.html#a1cc210d2cb7b74e71275e4595f84135a", null ],
     [ "do_get_outputs", "classIMP_1_1kernel_1_1Restraint.html#aaf0dbffa49774db873baa8c12a36715a", null ],
-    [ "get_input_containers", "classIMP_1_1kernel_1_1Restraint.html#a1696ddc9f5a6a76a36d4130070a65749", null ],
-    [ "get_input_particles", "classIMP_1_1kernel_1_1Restraint.html#a22c8f8eaea4a247be60414993929903b", null ],
     [ "get_last_score", "classIMP_1_1kernel_1_1Restraint.html#a9a6db13c4dbb901d5c37ff06b80fbd52", null ],
     [ "get_maximum_score", "classIMP_1_1kernel_1_1Restraint.html#a9376ef198701f42a9b012cecee1f7f70", null ],
     [ "get_score", "classIMP_1_1kernel_1_1Restraint.html#a5f8db4f6b123e470fc627d40561d4022", null ],
