@@ -1,10 +1,11 @@
 var classIMP_1_1multifit_1_1DummyRestraint =
 [
     [ "DummyRestraint", "classIMP_1_1multifit_1_1DummyRestraint.html#a3877741eb79414251e58cfd047c90dbb", null ],
+    [ "~DummyRestraint", "classIMP_1_1multifit_1_1DummyRestraint.html#af1f487bc8a61e22bdcfe9621d27b86ad", null ],
     [ "do_get_inputs", "classIMP_1_1multifit_1_1DummyRestraint.html#a6d281af5d2277ee15bd56298589b309f", null ],
     [ "get_type_name", "classIMP_1_1multifit_1_1DummyRestraint.html#a3e69866b3ce1a875fe016b2b032a717c", null ],
     [ "get_version_info", "classIMP_1_1multifit_1_1DummyRestraint.html#a1ad956d34e0e2ac5f59e64ccbb3aa0a9", null ],
-    [ "const", "classIMP_1_1multifit_1_1DummyRestraint.html#af13af81a75e497f0ef3c8b7a788d9283", null ],
+    [ "unprotected_evaluate", "classIMP_1_1multifit_1_1DummyRestraint.html#affa16e2ba9d9d5b915a75556dc35f0bc", null ],
     [ "p1_", "classIMP_1_1multifit_1_1DummyRestraint.html#ae671d726b2d115335c3c11f7b4e4f034", null ],
     [ "p2_", "classIMP_1_1multifit_1_1DummyRestraint.html#af134ec1936022d431c52e8fea4206c42", null ]
 ];
\ No newline at end of file
