@@ -1,6 +1,7 @@
 var classIMP_1_1multifit_1_1RadiusOfGyrationRestraint =
 [
     [ "RadiusOfGyrationRestraint", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#aa06cde84e63e6e318339885487a2ab37", null ],
+    [ "~RadiusOfGyrationRestraint", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#a2ea96e98e8caafe34f5c8b3e0f16c356", null ],
     [ "add_particle", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#a760c99763396d94c38fd817220b63f57", null ],
     [ "add_particles", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#a9b5c8a1a0c8b17b8daa986dbbd0cd263", null ],
     [ "clear_particles", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#aba0a61f0b7e2c0f7f21ae3ef974eb4b5", null ],
@@ -18,7 +19,7 @@ var classIMP_1_1multifit_1_1RadiusOfGyrationRestraint =
     [ "set_particles", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#a74f538601ea050b895e30770be06b3c2", null ],
     [ "set_particles_order", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#a01913f7603432de3f21829a3345714a2", null ],
     [ "set_radius_of_gyration", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#a88174776515fb9fb9725bd91c725fe7e", null ],
-    [ "const", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#a60f530e3d187b4b082b6d4ea8e76bdef", null ],
+    [ "unprotected_evaluate", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#ad0c7d950074ecb7fdd3ed35878945f3e", null ],
     [ "hub_", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#a93fe6141693690dc4ddace1d91ffccdc", null ],
     [ "mdl_", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#af833fbea7b75ff05f068abf783d8137d", null ],
     [ "predicted_rog_", "classIMP_1_1multifit_1_1RadiusOfGyrationRestraint.html#a574d11ca3a10f5473763543b9036eab8", null ],
