@@ -1,6 +1,7 @@
 var classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint =
 [
     [ "WeightedExcludedVolumeRestraint", "classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint.html#a1b6c81a897d408afc71a09df136738c3", null ],
+    [ "~WeightedExcludedVolumeRestraint", "classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint.html#a4b3048ee222265eaed7a4edee3ee7469", null ],
     [ "add_particle", "classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint.html#ac8715c7130d23290d5a58ed5b3868a3a", null ],
     [ "add_particles", "classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint.html#af00b374b5f4b97542ffdb9db112c73ac", null ],
     [ "clear_particles", "classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint.html#a3f6519c55b712437e0d256345c1f3762", null ],
@@ -16,5 +17,5 @@ var classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint =
     [ "reserve_particles", "classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint.html#afc32b0b883fc7ed868bfc1d26d83c523", null ],
     [ "set_particles", "classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint.html#aca17d1d2c7d7ef23a8d7769abed68e20", null ],
     [ "set_particles_order", "classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint.html#a970f43e13202c1d527630a1b92b20e3b", null ],
-    [ "const", "classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint.html#a0ace008761f74a573b67a4fd7bf811c6", null ]
+    [ "unprotected_evaluate", "classIMP_1_1multifit_1_1WeightedExcludedVolumeRestraint.html#a65e794477f6b861c20211dd12b8dccc5", null ]
 ];
\ No newline at end of file
