@@ -3,10 +3,10 @@ var classIMP_1_1saxs_1_1RadialDistributionFunction =
     [ "RadialDistributionFunction", "classIMP_1_1saxs_1_1RadialDistributionFunction.html#aac188b0b50acb2298803da1a8c2db43e", null ],
     [ "RadialDistributionFunction", "classIMP_1_1saxs_1_1RadialDistributionFunction.html#adce14ffe1c86faa5df2e469d1f6e8144", null ],
     [ "add", "classIMP_1_1saxs_1_1RadialDistributionFunction.html#aeb53667c6c8b782418cc9189c9bd0a12", null ],
+    [ "add_to_distribution", "classIMP_1_1saxs_1_1RadialDistributionFunction.html#adbcb2a8509106c87d129314dd56feda0", null ],
     [ "fit", "classIMP_1_1saxs_1_1RadialDistributionFunction.html#ae721522ec9a73d6d7a0ca6d70f8c26b0", null ],
     [ "normalize", "classIMP_1_1saxs_1_1RadialDistributionFunction.html#a591cb35b054a4266669f4e82698c0cc7", null ],
     [ "R_factor_score", "classIMP_1_1saxs_1_1RadialDistributionFunction.html#a6db926a74bb65954241a8ed464bc21e0", null ],
     [ "scale", "classIMP_1_1saxs_1_1RadialDistributionFunction.html#ad97281975269578afb735ff944103626", null ],
-    [ "show", "classIMP_1_1saxs_1_1RadialDistributionFunction.html#a3e4067f6a15136defefd384eb076e0a6", null ],
-    [ "Profile", "classIMP_1_1saxs_1_1RadialDistributionFunction.html#ae2b45580605bfe4f246c9dc5f5bdc4ff", null ]
+    [ "show", "classIMP_1_1saxs_1_1RadialDistributionFunction.html#a3e4067f6a15136defefd384eb076e0a6", null ]
 ];
\ No newline at end of file
