@@ -1,8 +1,9 @@
 var classIMP_1_1saxs_1_1RadiusOfGyrationRestraint =
 [
     [ "RadiusOfGyrationRestraint", "classIMP_1_1saxs_1_1RadiusOfGyrationRestraint.html#aa1802c804fb1f62b6678c9b2b860b1f8", null ],
+    [ "~RadiusOfGyrationRestraint", "classIMP_1_1saxs_1_1RadiusOfGyrationRestraint.html#a56599dfcb5b55edbecdbcb08df2b45c1", null ],
     [ "do_get_inputs", "classIMP_1_1saxs_1_1RadiusOfGyrationRestraint.html#ac66778d8750f790ba673e67925776434", null ],
     [ "get_type_name", "classIMP_1_1saxs_1_1RadiusOfGyrationRestraint.html#a8fa4c365f036a11af03fd1ab61be9aec", null ],
     [ "get_version_info", "classIMP_1_1saxs_1_1RadiusOfGyrationRestraint.html#a9821a13382dc7a0c51fd66fe94ee2f42", null ],
-    [ "const", "classIMP_1_1saxs_1_1RadiusOfGyrationRestraint.html#a27c0a89d657ba13fb19cb18f38a4d6f3", null ]
+    [ "unprotected_evaluate", "classIMP_1_1saxs_1_1RadiusOfGyrationRestraint.html#ac797818869c4a4f92b4c51f4f35aad4d", null ]
 ];
\ No newline at end of file
