@@ -1,5 +1,9 @@
 var hierarchical__clustering_8h =
 [
+    [ "AverageDistanceLinkage", "classIMP_1_1em2d_1_1AverageDistanceLinkage.html", "classIMP_1_1em2d_1_1AverageDistanceLinkage" ],
+    [ "ClusterSet", "classIMP_1_1em2d_1_1ClusterSet.html", "classIMP_1_1em2d_1_1ClusterSet" ],
+    [ "CompleteLinkage", "classIMP_1_1em2d_1_1CompleteLinkage.html", "classIMP_1_1em2d_1_1CompleteLinkage" ],
+    [ "SingleLinkage", "classIMP_1_1em2d_1_1SingleLinkage.html", "classIMP_1_1em2d_1_1SingleLinkage" ],
     [ "AverageDistanceLinkages", "hierarchical__clustering_8h.html#a25f136e1ddd4ca1cdf3a5424779ba96f", null ],
     [ "ClusterSets", "hierarchical__clustering_8h.html#a62990962806750333a51ab578ad82836", null ],
     [ "CompleteLinkages", "hierarchical__clustering_8h.html#a35a2555b711fbdf91e8c5d9f1e7bb7db", null ],
