@@ -104,6 +104,7 @@ var namespaceIMP_1_1core =
     [ "RigidBodyMover", "classIMP_1_1core_1_1RigidBodyMover.html", "classIMP_1_1core_1_1RigidBodyMover" ],
     [ "RigidBodyTorque", "classIMP_1_1core_1_1RigidBodyTorque.html", "classIMP_1_1core_1_1RigidBodyTorque" ],
     [ "RigidBodyTunneler", "classIMP_1_1core_1_1RigidBodyTunneler.html", "classIMP_1_1core_1_1RigidBodyTunneler" ],
+    [ "RigidBodyUmbrella", "classIMP_1_1core_1_1RigidBodyUmbrella.html", "classIMP_1_1core_1_1RigidBodyUmbrella" ],
     [ "RigidClosePairsFinder", "classIMP_1_1core_1_1RigidClosePairsFinder.html", "classIMP_1_1core_1_1RigidClosePairsFinder" ],
     [ "RigidMember", "classIMP_1_1core_1_1RigidMember.html", "classIMP_1_1core_1_1RigidMember" ],
     [ "SerialMover", "classIMP_1_1core_1_1SerialMover.html", "classIMP_1_1core_1_1SerialMover" ],
@@ -129,6 +130,7 @@ var namespaceIMP_1_1core =
     [ "UnorderedTypeSingletonPredicate", "classIMP_1_1core_1_1UnorderedTypeSingletonPredicate.html", "classIMP_1_1core_1_1UnorderedTypeSingletonPredicate" ],
     [ "UnorderedTypeTripletPredicate", "classIMP_1_1core_1_1UnorderedTypeTripletPredicate.html", "classIMP_1_1core_1_1UnorderedTypeTripletPredicate" ],
     [ "VolumeRestraint", "classIMP_1_1core_1_1VolumeRestraint.html", "classIMP_1_1core_1_1VolumeRestraint" ],
+    [ "WeightedDerivativesToRefined", "classIMP_1_1core_1_1WeightedDerivativesToRefined.html", "classIMP_1_1core_1_1WeightedDerivativesToRefined" ],
     [ "WeightedSphereDistancePairScore", "classIMP_1_1core_1_1WeightedSphereDistancePairScore.html", "classIMP_1_1core_1_1WeightedSphereDistancePairScore" ],
     [ "WriteRestraintScoresOptimizerState", "classIMP_1_1core_1_1WriteRestraintScoresOptimizerState.html", "classIMP_1_1core_1_1WriteRestraintScoresOptimizerState" ],
     [ "XYZ", "classIMP_1_1core_1_1XYZ.html", "classIMP_1_1core_1_1XYZ" ],
