@@ -22,19 +22,19 @@ rh = RMF.create_rmf_file(tfn)
 IMP.rmf.add_hierarchies(rh, [h])
 
 # add the current configuration to the file as frame 0
-IMP.rmf.save_frame(rh, 0)
+IMP.rmf.save_frame(rh)
 
 # change a coordinate
 IMP.core.XYZ(IMP.atom.get_leaves(h)[0]).set_x(0)
 
 # add the new configuration to the file as frame 1
-IMP.rmf.save_frame(rh, 1)
+IMP.rmf.save_frame(rh)
 
 # close the file
 del rh
 
 # reopen it, don't clear the file when opening it
-rh = RMF.open_rmf_file(tfn)
+rh = RMF.open_rmf_file_read_only(tfn)
 
 # hps is a list with one element which is a copy of h
 hps = IMP.rmf.create_hierarchies(rh, m)
@@ -42,6 +42,6 @@ hps = IMP.rmf.create_hierarchies(rh, m)
 IMP.atom.show_molecular_hierarchy(hps[0])
 
 # load the second configuration into hps
-IMP.rmf.load_frame(rh, 0)
+IMP.rmf.load_frame(rh, RMF.FrameID(0))
 
 print "Try running hdf5_display or hdf5_show on", tfn
